@@ -1,5 +1,6 @@
 """Celery result backends for Django."""
 # :copyright: (c) 2016, Ask Solem.
+# :copyright: (c) 2017-2033, Asif Saif Uddin.
 #             All rights reserved.
 # :license:   BSD (3 Clause), see LICENSE for more details.
 
@@ -8,9 +9,9 @@ from collections import namedtuple
 
 import django
 
-__version__ = '2.4.0'
+__version__ = '2.5.1'
 __author__ = 'Asif Saif Uddin, Ask Solem'
-__contact__ = 'auvipy@gmai.com, ask@celeryproject.org'
+__contact__ = 'auvipy@gmail.com'
 __homepage__ = 'https://github.com/celery/django-celery-results'
 __docformat__ = 'restructuredtext'
 
@@ -26,8 +27,8 @@ _temp = re.match(
     r'(\d+)\.(\d+).(\d+)(.+)?', __version__).groups()
 VERSION = version_info = version_info_t(
     int(_temp[0]), int(_temp[1]), int(_temp[2]), _temp[3] or '', '')
-del(_temp)
-del(re)
+del _temp
+del re
 
 __all__ = []
 
