@@ -2,7 +2,7 @@ import binascii
 import json
 
 from celery import maybe_signature
-from celery.backends.base import BaseDictBackend
+from celery.backends.base import BaseDictBackend, get_current_task
 from celery.exceptions import ChordError
 from celery.result import GroupResult, allow_join_result, result_from_tuple
 from celery.utils.log import get_logger
@@ -99,6 +99,16 @@ class DatabaseBackend(BaseDictBackend):
 
         return extended_props
 
+    def _get_meta_from_request(self, request=None):
+        """
+        Use the request or get_current_task to evaluate the `meta` attribute.
+
+        With this, is possible to assign arbitrary data in request.meta to be
+        retrieve and stored on the TaskResult.
+        """
+        request = request or getattr(get_current_task(), "request", None)
+        return getattr(request, "meta", {})
+
     def _store_result(
             self,
             task_id,
@@ -110,14 +120,19 @@ class DatabaseBackend(BaseDictBackend):
     ):
         """Store return value and status of an executed task."""
         content_type, content_encoding, result = self.encode_content(result)
-        _, _, meta = self.encode_content(
-            {'children': self.current_task_children(request)}
+
+        meta = {
+            **self._get_meta_from_request(request),
+            "children": self.current_task_children(request),
+        }
+        _, _, encoded_meta = self.encode_content(
+            meta,
         )
 
         task_props = {
             'content_encoding': content_encoding,
             'content_type': content_type,
-            'meta': meta,
+            'meta': encoded_meta,
             'result': result,
             'status': status,
             'task_id': task_id,
@@ -236,16 +251,17 @@ class DatabaseBackend(BaseDictBackend):
             # wrap the update in a transaction
             # with a `select_for_update` lock to prevent race conditions.
             # SELECT FOR UPDATE is not supported on all databases
-            chord_counter = (
-                ChordCounter.objects.select_for_update()
-                .filter(group_id=gid).first()
-            )
-            if chord_counter is None:
+            try:
+                chord_counter = (
+                    ChordCounter.objects.select_for_update()
+                    .get(group_id=gid)
+                )
+            except ChordCounter.DoesNotExist:
                 logger.warning("Can't find ChordCounter for Group %s", gid)
                 return
             chord_counter.count -= 1
             if chord_counter.count != 0:
-                chord_counter.save()
+                chord_counter.save(update_fields=["count"])
             else:
                 # Last task in the chord header has finished
                 call_callback = True
