@@ -1,20 +1,15 @@
-from __future__ import absolute_import, unicode_literals
-
-import pytest
 import sys
-
 from datetime import timedelta
 
+import pytest
 from billiard.einfo import ExceptionInfo
-
-from celery import result
-from celery import states
-from celery import uuid
+from celery import result, states, uuid
+from kombu.utils.encoding import bytes_to_str
 
 from django_celery_results.backends.cache import CacheBackend
 
 
-class SomeClass(object):
+class SomeClass:
 
     def __init__(self, data):
         self.data = data
@@ -65,6 +60,18 @@ class test_CacheBackend:
         assert rindb.get('foo') == 'baz'
         assert rindb.get('bar').data == 12345
 
+    def test_convert_key_from_byte_to_str(self):
+        """ Tests that key in byte form passed into cache
+            are succesfully completed """
+        tid = bytes_to_str(uuid())
+
+        assert self.b.get_status(tid) == states.PENDING
+        assert self.b.get_result(tid) is None
+
+        self.b.mark_as_done(tid, 42)
+        assert self.b.get_status(tid) == states.SUCCESS
+        assert self.b.get_result(tid) == 42
+
     def test_mark_as_failure(self):
         einfo = None
         tid3 = uuid()
